@@ -4,10 +4,8 @@ metadata API with built-in pandas integration
 '''
 
 import urllib.parse
-import re
 from functools import reduce
 import requests
-import warnings
 from tabulate import tabulate
 from . import series
 from . import source
@@ -18,9 +16,6 @@ from . import income
 from . import lending
 from . import topic
 from . import data
-
-from .__version__ import __version__
-
 try:
     import pandas as pd
 except ImportError:
@@ -32,8 +27,7 @@ endpoint = 'https://api.worldbank.org/v2'
 lang = 'en'
 per_page = 1000          # you can increase this if you start getting 'service unavailable' messages, which can mean you're sending too many requests per minute
 db = 2
-proxies = None           # deprecated
-get_options = {}         # additional parameters passed to requests.get
+proxies = None           # see https://requests.readthedocs.io/en/master/user/advanced/#proxies for format
 
 # The maximum URL length is 1500 chars before it reports a server error. Internally we use a smaller
 # number for head room as well as to provide for the query string
@@ -51,41 +45,21 @@ class APIError(Exception):
 
     return 'APIError: {} ({})'.format(self.msg, self.url)
 
-class APIResponseError(APIError):
-    '''This error indicates that the module didn't understand the response from the API.
-    Either it couldn't parse the JSON (the API sometimes returns XML even when JSON is
-    requested) or it doesn't recognize the json schema
-    '''
-    def __init__(self, url, msg):
-        super(APIResponseError,self).__init__(url, msg)
-
-    pass
-
 class URLError(Exception):
     pass
 
 class Metadata():
-    def __init__(self,concept,id,name):
+    def __init__(self,concept,id):
         self.concept = concept
         self.id = id
-        self.name = name
         self.metadata = {}
 
     def __repr__(self):
-        return self.repr()
-
-    def repr(self, q=None, padding=None):
-        '''Same as __repr__ but includes formatting options
-        '''
 
         def segment(d):
-            return '\n--------\n'.join(['{}: {}'.format(k, abbreviate(v, q=q, padding=padding)) for k,v in d.items()]) + '\n'
+            return '\n--------\n'.join(['{}: {}'.format(k, v) for k,v in d.items()]) + '\n'
             
-        label = self.id
-        if self.name:
-            label += ', ' + self.name
-
-        s = '========\n{}: {}\n\n'.format(self.concept, label) +  segment(self.metadata)
+        s = '========\n{}: {}\n\n'.format(self.concept, self.id) +  segment(self.metadata)
 
         subsets = {'series': 'Economy-Series', 'economies': 'Series-Economy', 'time': 'Series-Time'}
         for k,v in subsets.items():
@@ -98,10 +72,8 @@ class Metadata():
 
     def _repr_html_(self):
 
-        def segment(concept, meta, id=None, name=None):
-            if id and name:
-                s = '<h4>{}: {}, {}</h4>'.format(concept, id, name)
-            elif id:
+        def segment(concept, meta, id=None):
+            if id:
                 s = '<h4>{}: {}</h4>'.format(concept, id)
             else:
                 s = '<h5>{}</h5>'.format(concept)
@@ -111,9 +83,9 @@ class Metadata():
                 rows.append([k, v])
 
             # here we don't call htmlTable because we wrap the entire output in a <div/>
-            return s + tabulate(rows, tablefmt='html', headers=['Field', 'Value'])
+            return s + tabulate(rows, tablefmt='html', headers=['field', 'value'])
 
-        s = '<div class="wbgapi">' + segment(self.concept, self.metadata, id=self.id, name=self.name)
+        s = '<div class="wbgapi">' + segment(self.concept, self.metadata, id=self.id)
         subsets = {'series': 'Economy-Series', 'economies': 'Series-Economy', 'time': 'Series-Time'}
         for k,v in subsets.items():
             if hasattr(self, k):
@@ -124,64 +96,6 @@ class Metadata():
         return s + '</div>'
 
 
-class MetadataCollection():
-    def __init__(self, brief=False, padding=80, q=None):
-        self.metadata = {}
-        self.brief = brief
-        self.padding = padding
-        self.q = q
-
-    def append(self, meta):
-        '''Append a Metadata object to our store
-        '''
-
-        if meta.concept not in self.metadata:
-            self.metadata[meta.concept] = []
-
-        self.metadata[meta.concept].append(meta)
-
-    def brief_table(self, tablefmt):
-        rows = []
-        for concept in self.metadata.values():
-            for elem in concept:
-                rows.append([elem.concept, elem.id, elem.name])
-
-        return tabulate(rows, tablefmt=tablefmt, headers=['Concept', 'ID', 'Name'])
-        
-    def __repr__(self):
-        s = ''
-        
-        if len(self.metadata) == 0:
-            return 'No match'
-
-        if self.brief:
-            return self.brief_table('simple')
-
-        for concept in self.metadata.values():
-            for elem in concept:
-                s += elem.repr(q=self.q, padding=self.padding)
-
-        return s
-
-    def _repr_html_(self):
-        if len(self.metadata) == 0:
-            return '<div class="wbgapi"><p class="nomatch">No match</p></div>'
-
-        s = '<div class="wbgapi">'
-        if self.brief:
-            s += self.brief_table('html')
-        else:
-            for concept,hits in self.metadata.items():
-                s += '<h4>{}</h4>'.format(concept)
-                rows = []
-                for metadata in hits:
-                    for k,v in metadata.metadata.items():
-                        rows.append([metadata.id, metadata.name, k, abbreviate(v, q=self.q, padding=self.padding)])
-
-                s += tabulate(rows, tablefmt='html', headers=['ID', 'Name', 'Field', 'Value'])
-
-        return s + '</div>'
-        
 class Featureset():
     def __init__(self, items, columns=None):
         ''' can be initialized with any iterable
@@ -393,67 +307,34 @@ def metadata(url, variables, concepts='all', **kwargs):
         for var in concept['variable']:
             id = var['id']
             for field in var['metatype']:
-                yield (concept['id'], var['id'], var.get('name'), field)
+                yield (concept['id'], var['id'], field)
     
-    m = Metadata(None,None,None)
+    m = Metadata(None,None)
     for row in refetch(url, variables, concepts=True, **kwargs):
         if concepts and row['id'] not in concepts:
             continue
 
-        for (concept_name,variable_id,variable_name,field) in metafield(row):
+        for (concept_name,variable_id,field) in metafield(row):
             if concept_name != m.concept or variable_id != m.id:
                 if m.concept:
                     yield m
 
-                m = Metadata(concept_name, variable_id, variable_name)
+                m = Metadata(concept_name, variable_id)
             
             m.metadata[field['id']] = field['value']
 
     if m.concept:
         yield m
 
-def search(q, footnotes='none', brief=False, padding=80, db=None):
-    '''search database metadata and return results as a print-friendly object
+def search(q, concepts='all', db=None):
+    ''' search database metadata for matching text.
 
     Arguments:
-        q:          search term
+        url:        url with tokens, as per refetch()
 
-        footnotes:  how to treat footnotes: 'include', 'only', or 'none'
+        concepts:   Name or list-like of the concepts to return: 'all' for all concepts
 
-        brief:      abbreviated output (don't print matching values)
-
-        padding:    approximate number of surrounding characters to include when displaying text matching
-                    the search term. None returns the entire string
-
-        db:         database; pass None to access the global database
-
-    Returns:
-        a print-friendly object
-
-    Notes:
-        This function just provides a print-friendly front end to search2. If you need to
-        access search results programmatically, call search2 directly.
-
-    Examples:
-        wbgapi.search('fossil fuels')
-    '''
-
-    result = MetadataCollection(brief=brief, q=q, padding=padding)
-
-    for row in search2(q, footnotes=footnotes, db=db):
-        result.append(row)
-
-    return result
-
-def search2(q, footnotes='none',  db=None):
-    ''' search database metadata for matching text, returning a generator
-
-    Arguments:
-        q:          search term
-
-        footnotes:  how to treat footnotes: 'include', 'only', or 'none'
-
-        db:         database; pass None to access the global database
+        **kwargs:   Remaining arguments to pass to refetch (must include varables for tokens in url)
 
     Returns:
         a generator that provides Metadata objects (same as metadata())
@@ -463,7 +344,7 @@ def search2(q, footnotes='none',  db=None):
         is that the metadata property contains matching metadata fields and values.
 
     Examples:
-        for row in wbgapi.search2('fossil fuels'):
+        for row in wbgapi.search('fossil fuels'):
             print(row)
 
     '''
@@ -471,14 +352,8 @@ def search2(q, footnotes='none',  db=None):
     if db is None:
         db = globals()['db']
 
-    try:
-        for row in metadata('sources/{source}/search/{q}', ['source'], source=str(db), q=urllib.parse.quote(q, safe='')):
-            concept = row.concept.lower()
-            if (concept == 'footnote' and footnotes != 'none') or (concept != 'footnote' and footnotes != 'only'):
-                yield row
-    except APIResponseError:
-        # if there are no matches, the API returns an error in xml format
-        pass
+    for row in metadata('sources/{source}/search/{q}', ['source'], concepts=concepts, source=str(db), q=urllib.parse.quote(q, safe='')):
+        yield row
 
 def _responseHeader(url, result):
     '''Internal function to return the response header, which contains page information
@@ -520,19 +395,16 @@ def _responseObjects(url, result, wantConcepts=False):
 def _queryAPI(url):
     '''Internal function for calling the API with sanity checks
     '''
-    params = get_options.copy()
-    if proxies:
-        warnings.warn('"proxies" is deprecated and will be removed in a future release. Use "get_options" instead as described in the README', DeprecationWarning)
-        params['proxies'] = proxies
+    global proxies
 
-    response = requests.get(url, **params)
+    response = requests.get(url, proxies=proxies)
     if response.status_code != 200:
         raise APIError(url, response.reason, response.status_code)
 
     try:
         result = response.json()
     except:
-        raise APIResponseError(url, 'JSON decoding error')
+        raise APIError(url, 'JSON decoding error')
 
     hdr = _responseHeader(url, result)
     if hdr.get('message'):
@@ -541,7 +413,7 @@ def _queryAPI(url):
 
     return (hdr, result)
 
-_concept_mrv_cache = {}
+_latest_concept_cache = {}
 
 def queryParam(arg, concept=None, db=None):
     ''' Prepare parameters for an API query. This is a core function
@@ -562,16 +434,16 @@ def queryParam(arg, concept=None, db=None):
         db = globals()['db']
 
     if type(arg) is str and arg == 'mrv' and concept:
-        global _concept_mrv_cache
+        global _latest_concept_cache
 
-        if _concept_mrv_cache.get(db) is None:
-            _concept_mrv_cache[db] = {}
+        if _latest_concept_cache.get(db) is None:
+            _latest_concept_cache[db] = {}
 
-        if _concept_mrv_cache[db].get(concept) is None:
-            for row in source.features(concept, db=db):
-                _concept_mrv_cache[db][concept] = row['id']
+        if _latest_concept_cache[db].get(concept) is None:
+            for row in source.features(concept):
+                _latest_concept_cache[db][concept] = row['id']
 
-        arg = _concept_mrv_cache[db].get(concept, '')
+        arg = _latest_concept_cache[db].get(concept, '')
         
     if type(arg) is str or type(arg) is int:
         arg = [arg]
@@ -583,12 +455,12 @@ def queryParam(arg, concept=None, db=None):
     # this will throw an exception if arg is not iterable, which is what we want it to do
     return ';'.join(map(lambda x:str(x), arg))
 
-def Series(data, key='id', value='value', name=None):
-    '''Convert a list-like to a pandas Series object. This core function is
-    called by several dimension-specific implementation functions.
+def pandasSeries(data, key='id',value='value',name=None):
+    '''Convert an object array to a pandas Series object. This core function is
+    called by several dimension-specific implementation functions
 
     Arguments:
-        data:       an object array, generator, or function that returns a list-like
+        data:       an object array. Each object becomes a Series row
 
         key:        field for the Series index
 
@@ -598,13 +470,6 @@ def Series(data, key='id', value='value', name=None):
 
     Returns:
         a pandas Series object
-    
-    Example:
-        Generally you are better off calling the Series function for a specific feature
-        e.g., wbgapi.time.Series(). Direct calls should only be necessary for databases
-        with custom dimensions, for instance:
-
-        wbgapi.Series(wbgapi.source.features('version', db=57))
     '''
 
     
@@ -614,9 +479,6 @@ def Series(data, key='id', value='value', name=None):
     if name is None:
         name = value
 
-    if callable(data):
-        data = data()
-
     return pd.Series({row[key]: row[value] for row in data}, name=name)
 
 def htmlTable(*args, **kwargs):
@@ -627,25 +489,6 @@ def htmlTable(*args, **kwargs):
 
     return '<div class="wbgapi">' + tabulate(*args, tablefmt='html', **kwargs) + '</div>'
 
-def abbreviate(text, q=None, padding=80):
-    '''Returns a shortened version of the text string comprised of the search pattern
-    and a specified number of characters on either side. This is used to optimize
-    search results. If the search pattern 
-    '''
-
-    match = None
-    if q and padding is not None:
-        if padding > 0:
-            pattern = '(?<!\w).{{0,{len}}}{term}.{{0,{len}}}(?!\w)'.format(term=re.escape(q), len=padding)
-            match = re.search(pattern, text, re.IGNORECASE)
-        else:
-            match = re.search(q, text, re.IGNORECASE)
-
-    if match and len(match.group(0)) + 6 < len(text):
-        return '...' + match.group(0) + '...'
-        
-    return text
-
 def _refetch_url(url, var, variables, **kwargs):
     '''Used to chunk potentially very long URLs smaller ones by splitting long arguments
 
